#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# asyncqlio documentation build configuration file, created by
# sphinx-quickstart on Wed Apr 26 07:56:32 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#

import guzzle_sphinx_theme
from pkg_resources import DistributionNotFound, get_distribution

try:
    _release = get_distribution('asyncqlio')
except DistributionNotFound:
    version = "0.0.0"
    release = "0.0.0"
else:
    version = '.'.join(_release.version.split(".")[:3])
    release = _release.version

# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.autodoc',
              'sphinx.ext.doctest',
              'sphinx.ext.intersphinx',
              'sphinx.ext.coverage',
              'sphinx.ext.ifconfig',
              'sphinx.ext.viewcode',
              'sphinx.ext.autosummary',
              'sphinxcontrib.asyncio',
              # 'sphinx_autodoc_typehints'
              ]

# Autodoc config
autoclass_content = 'both'  # include both class docstring and __init__
autodoc_default_flags = [
    # Make sure that any autodoc declarations show the right members
    'members',
    'inherited-members',
    'show-inheritance',
]
# make autodoc look less... bad
autodoc_member_order = "bysource"

# auto-generate autosummary pages.
autosummary_generate = True

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = 'asyncqlio'
copyright = '2017, Laura Dickinson'
author = 'Laura Dickinson'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#

# defined above

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'manni'

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False

# html theme
html_theme_path = guzzle_sphinx_theme.html_theme_path()
html_theme = 'guzzle_sphinx_theme'

html_static_path = ['_static']

# Output file base name for HTML help builder.
htmlhelp_basename = 'asyncqlio_doc'

# misc bs
latex_elements = {
}

latex_documents = [
    (master_doc, 'asyncqlio.tex', 'asyncqlio Documentation',
     'Laura Dickinson', 'manual'),
]

man_pages = [
    (master_doc, 'asyncqlio', 'asyncqlio Documentation',
     [author], 1)
]

texinfo_documents = [
    (master_doc, 'asyncqlio', 'asyncqlio Documentation',
     author, 'asyncqlio', 'One line description of project.',
     'Miscellaneous'),
]

# Bibliographic Dublin Core info.
epub_title = project
epub_author = author
epub_publisher = author
epub_copyright = copyright

# A list of files that should not be packed into the epub file.
epub_exclude_files = ['search.html']

# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {'https://docs.python.org/3/': None}
